#include "test/Service.h"

#include <nlohmann/json.hpp>

#include <memory>


namespace xs { namespace test 
{
    Service::Service(const nlohmann::json& object)
    : Service(
        object[object.count("command") ? "command" : "event"].get<std::string>()
    )
    {
        if (object.count("command")) {
            response_ = object["response"];
        }
    }

    bool Service::verify(const nlohmann::json& object) noexcept
    {
        if (!object.is_object()) {
            return false;
        }

        if (object.count("command")) {
            return object["command"].is_string()
                && (object["response"].is_string() || object["response"].is_object())
                ;
        } else if (object.count("event")) {
            return object["event"].is_string();
        }

        return false;
    }

    Service::Service(std::string name) noexcept
    : name_(std::move(name))
    , response_(boost::none)
    { }

    bool Service::isCommand() const noexcept
    {
        return static_cast<bool>(response_);
    }

    bool Service::isEvent() const noexcept
    {
        return !isCommand();
    }
} }
